@@ -11,10 +11,6 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-#
-# ================================================================================================
-
-from __future__ import absolute_import
 
 from neal.sampler import *
 import neal.sampler
